==> prayer-1.0.12.tar.gz: prayer-1.0.12/prayer/cmd_abook_xfer.c <==
/* $Cambridge: hermes/src/prayer/prayer/cmd_abook_xfer.c,v 1.1.1.1 2003/04/15 13:00:03 dpc22 Exp $ */
/************************************************
 *    Prayer - a Webmail Interface              *
 ************************************************/

/* Copyright (c) University of Cambridge 2000 - 2002 */
/* See the file NOTICE for conditions of use and distribution. */

#include "prayer_session.h"

/* Transfer addressbook to/from local system */

static void generate_form(struct session *session)
{
    struct request *request = session->request;
    struct buffer *b = request->write_buffer;

    /* Title bar */
    html_start(session, b, "Addressbook Transfer");
    html_banner_toolbar(session, b, "abook_xfer", 0);

    /* Title line */
    bprintf(b, "<h2 align=\"center\">Addressbook Transfer</h2>" CRLF);

    /* Miscelleneous Actions */
    bputs(b,
          "<table width=\"100%\"><tr><td align=\"right\"><table><tr>"
          CRLF);

    html_textlink_session_table(session, b, "abook_list", "Cancel");
    bputs(b, "<td>|</td>");

    bprintf(b, ("<td><a href=\"%s/NOSEQ/abook_xfer/export/addressbook\">"
                "Export to Local System</td>"),
            session->url_prefix_bsession);

    bputs(b, "</tr></table></td></tr></table>" CRLF);

    /* Addressbook import */

    bputs(b, "<table><tr>" CRLF);
    bputs(b, "<td>File:</td>" CRLF);
    bputs(b, "<td>" CRLF);
    html_session_bputs(session, b,
                       "<form method=\"POST\" action=\"",
                       "\" enctype=\"multipart/form-data\">" CRLF,
                       "abook_xfer/import");

    bputs(b, ("<input align=\"middle\" size=\"40\" "
              "type=\"file\" name=\"file\">" CRLF));
    bputs(b,
          "<input type=\"submit\" value=\"Import Pine format Addressbook\">");
    bputs(b, "</form>" CRLF);
    bputs(b, "</td>" CRLF);
    bputs(b, "</tr></table>" CRLF);

    /* Miscelleneous Actions 2 */
    if (session->accountd_server && session->accountd_server[0]) {
        struct config *config = session->config;

        bputs(b,
              "<table width=\"100%\"><tr><td align=\"right\"><table><tr>"
              CRLF);

        if (config->login_service_name && config->login_service_name[0]) {
            char *text;

            text =
                pool_printf(request->pool,
                            "Import from %s Pine addressbook",
                            config->login_service_name);

            html_textlink_session_table(session, b, "abook_import", text);

            bputs(b, "<td>|</td>");

            text =
                pool_printf(request->pool, "Export to %s Pine addressbook",
                            config->login_service_name);
            html_textlink_session_table(session, b, "abook_export", text);
        } else {
            html_textlink_session_table(session, b, "abook_import",
                                        "Import from Unix Pine addressbook");
            bputs(b, "<td>|</td>");
            html_textlink_session_table(session, b, "abook_export",
                                        "Export to Unix Pine addressbook");

        }
        bputs(b, "</td></tr></table></td></tr></table>" CRLF);
    }

    html_end(b);
    response_html(request, 200);        /* Success */
}

/* ====================================================================== */

/* Export Pine format addressbook */

static BOOL export(struct session *session)
{
    struct request *request = session->request;
    struct options *options = session->options;
    struct abook *abook = options->abook;
    struct buffer *b = request->write_buffer;
    char *name = "addressbook";

    bprintf(b, "# Prayer addressbook for %s\n", session->username);
    abook_export_buffer(abook, b);

    response_raw(request, name, "application/octet-stream", 200);

    return (T);
}

/* ====================================================================== */

void cmd_abook_xfer(struct session *session)
{
    struct request *request = session->request;
    char *start, *end;

    if (request->method != POST) {
        if ((request->argc >= 2) && !strcmp(request->argv[1], "export")) {
            export(session);
            return;
        }
        generate_form(session);
        return;
    }

    if (request->argc < 2) {
        session_redirect(session, request, "error");
        return;
    }

    request_decode_post_multipart(request, NIL, &start, &end);
    *end = '\0';

    if (!strncmp(start, "First Name\tLast Name\t",
                 strlen("First Name\tLast Name\t"))) {
        session_message(session,
                        "Outlook Express addressbooks not yet supported");
    } else if (abook_import_valid(start)) {
        struct abook *abook = session->options->abook;
        unsigned long count = abook_import(abook, start);

        if (count != 1)
            session_message(session, "Imported %lu aliases", count);
        else
            session_message(session, "Imported 1 alias");

        if (count > 0)
            session->options->save = T;
    } else
        session_message(session, "Invalid/Unsupported addressbook format");

    session_redirect(session, request, "abook_list");
}

==> prayer-1.0.16.tar.gz: prayer-1.0.16/prayer/cmd_abook_xfer.c <==
/* $Cambridge: hermes/src/prayer/prayer/cmd_abook_xfer.c,v 1.5 2005/08/26 11:32:38 dpc22 Exp $ */
/************************************************
 *    Prayer - a Webmail Interface              *
 ************************************************/

/* Copyright (c) University of Cambridge 2000 - 2002 */
/* See the file NOTICE for conditions of use and distribution. */

#include "prayer_session.h"

/* Transfer addressbook to/from local system */

static void generate_form(struct session *session)
{
    struct request *request = session->request;
    struct buffer *b = request->write_buffer;

    /* Title bar */
    html_start(session, b, "Addressbook Transfer");
    html_banner_toolbar(session, b, "abook_xfer", 0);

    /* Title line */
    bprintf(b, "<h2 align=\"center\">Addressbook Transfer</h2>" CRLF);

    /* Miscelleneous Actions */
    bputs(b,
          "<table width=\"100%\"><tr><td align=\"right\"><table><tr>"
          CRLF);

    html_textlink_session_table(session, b, "abook_list", "Cancel");
    bputs(b, "<td>|</td>");

    bprintf(b, ("<td><a href=\"%s/NOSEQ/abook_xfer/export_csv/addressbook\">"
                "Export CSV (Outlook) addressbook</a></td>"),
            session->url_prefix_bsession);
    bputs(b, "<td>|</td>");
    bprintf(b, ("<td><a href=\"%s/NOSEQ/abook_xfer/export/addressbook\">"
                "Export PINE addressbook</a></td>"),
            session->url_prefix_bsession);
    bputs(b, "</tr></table></td></tr></table>" CRLF);

    /* Addressbook import */

    html_session_bputs(session, b,
                       "<form method=\"POST\" action=\"",
                       "\" enctype=\"multipart/form-data\">" CRLF,
                       "abook_xfer/import");
    bputs(b, "<table><tr>" CRLF);
    bputs(b, "<td>File:</td>" CRLF);
    bputs(b, "<td>" CRLF);
    bputs(b, ("<input align=\"middle\" size=\"40\" "
              "type=\"file\" name=\"file\">" CRLF));
    bputs(b, ("<input type=\"submit\" "
              "value=\"Import Addressbook\">"));
    bputs(b, "</td>" CRLF);
    bputs(b, "</tr></table>" CRLF);
    bputs(b, "</form>" CRLF);

    /* Miscelleneous Actions 2 */
    if (session->accountd_server && session->accountd_server[0]) {
        struct config *config = session->config;

        bputs(b,
              "<table width=\"100%\"><tr><td align=\"right\"><table><tr>"
              CRLF);

        if (config->login_service_name && config->login_service_name[0]) {
            char *text;

            text =
                pool_printf(request->pool,
                            "Import from %s Pine addressbook",
                            config->login_service_name);

            html_textlink_session_table(session, b, "abook_import", text);

            bputs(b, "<td>|</td>");

            text =
                pool_printf(request->pool, "Export to %s Pine addressbook",
                            config->login_service_name);
            html_textlink_session_table(session, b, "abook_export", text);
        } else {
            html_textlink_session_table(session, b, "abook_import",
                                        "Import from Unix Pine addressbook");
            bputs(b, "<td>|</td>");
            html_textlink_session_table(session, b, "abook_export",
                                        "Export to Unix Pine addressbook");

        }
        bputs(b, "</tr></table></td></tr></table>" CRLF);
    }

    html_end(b);
    response_html(request, 200);        /* Success */
}

/* ====================================================================== */

/* Export Pine format addressbook */

static BOOL export_pine(struct session *session)
{
    struct request *request = session->request;
    struct options *options = session->options;
    struct abook *abook = options->abook;
    struct buffer *b = request->write_buffer;
    char *name = "addressbook";

    bprintf(b, "# Prayer addressbook for %s\n", session->username);
    abook_export_pine(abook, b);

    response_raw(request, name, "application/octet-stream", 200);

    return (T);
}

/* ====================================================================== */

/* Export CSV (Outlook format) addressbook */

static BOOL export_csv(struct session *session)
{
    struct request *request = session->request;
    struct options *options = session->options;
    struct abook *abook = options->abook;
    struct buffer *b = request->write_buffer;
    char *name = "addressbook";

    abook_export_csv(abook, b);

    response_raw(request, name, "application/octet-stream", 200);

    return (T);
}

/* ====================================================================== */

void cmd_abook_xfer(struct session *session)
{
    struct request *request = session->request;
    char *start, *end;

    if (request->method != POST) {
        if ((request->argc >= 2) && !strcmp(request->argv[1], "export")) {
            export_pine(session);
            return;
        }
        if ((request->argc >= 2) && !strcmp(request->argv[1], "export_csv")) {
            export_csv(session);
            return;
        }
        generate_form(session);
        return;
    }

    if (request->argc < 2) {
        session_redirect(session, request, "error");
        return;
    }

    request_decode_post_multipart(request, NIL, &start, &end);
    *end = '\0';

    if (abook_import_csv_valid(start)) {
        struct abook *abook = session->options->abook;
        unsigned long count = abook_import_csv(abook, start);

        if (count != 1)
            session_message(session, "Imported %lu aliases", count);
        else
            session_message(session, "Imported 1 alias");

        if (count > 0)
            session->options->save = T;
    } else if (!strncmp(start, "First Name\tLast Name\t",
                        strlen("First Name\tLast Name\t"))) {
        /* XXX Test XXX */
        session_message(session,
                        "Old format Outlook addressbooks not supported");
    } else if (abook_import_pine_valid(start)) {
        struct abook *abook = session->options->abook;
        unsigned long count = abook_import_pine(abook, start);

        if (count != 1)
            session_message(session, "Imported %lu aliases", count);
        else
            session_message(session, "Imported 1 alias");

        if (count > 0)
            session->options->save = T;
    } else
        session_message(session, "Invalid/Unsupported addressbook format");

    session_redirect(session, request, "abook_list");
}
